@@ -1,19 +1,19 @@
 package Music::Intervals;
 our $AUTHORITY = 'cpan:GENE';
 
-# ABSTRACT: Breakdown of musical intervals
+# ABSTRACT: Breakdown of named musical intervals
 
 use strict;
 use warnings;
 
-our $VERSION = '0.0600';
+our $VERSION = '0.0601';
 
 use Algorithm::Combinatorics qw( combinations );
 use Math::Factor::XS qw( prime_factors );
 use Music::Chord::Namer qw( chordname );
 use MIDI::Pitch qw( name2freq );
-use Number::Fraction;
-use Music::Scales;
+use Number::Fraction ();
+use Music::Scales qw(get_scale_notes);
 use Music::Intervals::Ratios;
 use Moo;
 use strictures 2;
@@ -297,11 +297,11 @@ __END__
 
 =head1 NAME
 
-Music::Intervals - Breakdown of musical intervals
+Music::Intervals - Breakdown of named musical intervals
 
 =head1 VERSION
 
-version 0.0600
+version 0.0601
 
 =head1 SYNOPSIS
 
