@@ -1,14 +1,17 @@
 package Music::Intervals::Numeric;
 our $AUTHORITY = 'cpan:GENE';
-# ABSTRACT: Mathematical breakdown of musical intervals
+
+# ABSTRACT: Breakdown of numeric musical intervals
+
 use strict;
 use warnings;
-our $VERSION = '0.0200';
+
+our $VERSION = '0.0201';
 
 use Moo;
 use Algorithm::Combinatorics qw( combinations );
 use Math::Factor::XS qw( prime_factors );
-use Number::Fraction;
+use Number::Fraction ();
 use Music::Intervals::Ratios;
 
 
@@ -135,11 +138,11 @@ __END__
 
 =head1 NAME
 
-Music::Intervals::Numeric - Mathematical breakdown of musical intervals
+Music::Intervals::Numeric - Breakdown of numeric musical intervals
 
 =head1 VERSION
 
-version 0.0600
+version 0.0601
 
 =head1 SYNOPSIS
 
