@@ -1,9 +1,13 @@
 package Music::Intervals::Ratios;
-$Music::Intervals::Ratios::VERSION = '0.0600';
 our $AUTHORITY = 'cpan:GENE';
+
+# ABSTRACT: Musical ratios
+
 use strict;
 use warnings;
 
+our $VERSION = '0.0100';
+
 #> perl -Ilib -MMusic::Intervals::Ratios -le'$x=shift;print $Music::Intervals::Ratios::ratio->{$x}{name}' C
 #unison, perfect prime, tonic
 
@@ -1817,11 +1821,11 @@ __END__
 
 =head1 NAME
 
-Music::Intervals::Ratios
+Music::Intervals::Ratios - Musical ratios
 
 =head1 VERSION
 
-version 0.0600
+version 0.0601
 
 =head1 AUTHOR
 
